require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscspfsetting',
  dscmeta_resource_friendly_name: 'xSCSPFSetting',
  dscmeta_resource_name: 'MSFT_xSCSPFSetting',
  dscmeta_module_name: 'xSCSPF',
  dscmeta_module_version: '1.3.1.0',
  docs: 'The DSC xSCSPFSetting resource type.
         Automatically generated from version 1.3.1.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_settingtype: {
      type: "Enum['DatabaseConnectionString', 'EndPointConnectionString']",
      desc: 'Specifies either DatabaseConnectionString or EndPointConnectionString.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_servername: {
      type: 'String',
      desc: 'Specifies the name of the server the setting is associated with.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'An enumerated value that describes if the SPF setting exists. Present {default}   Absent    ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_value: {
      type: 'String',
      desc: 'Specifies the value for the setting.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies a friendly name for the setting.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scspfadmincredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential with admin permissions to Service Provider Foundation.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
